@@ -11,6 +11,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.gwt.user.server.rpc.RemoteServiceServlet;
+import com.liferay.portal.service.UserLocalServiceUtil;
 
 /**
  * The server side implementation of the RPC service.
@@ -27,28 +28,36 @@ public class SessionCheckerServiceImpl extends RemoteServiceServlet implements
 	 * @return .
 	 */
 	private ASLSession getASLSession() {	
-		try {
-			String sessionID = this.getThreadLocalRequest().getSession().getId();
-			String user = (String) this.getThreadLocalRequest().getSession().getAttribute(ScopeHelper.USERNAME_ATTRIBUTE);
-			System.out.println("***SessionCheckerServiceImpl USER = " + user + " ID = " + sessionID);
-			SessionManager manager = SessionManager.getInstance();
-			ASLSession toReturn = manager.getASLSession(sessionID, user);
-			return toReturn;
-		}
-		catch (NullPointerException e) {
-			_log.warn("Session is null, perhaps you refreshed your application");
-			return null;
-		}
+		String sessionID = this.getThreadLocalRequest().getSession().getId();
+		String user = (String) this.getThreadLocalRequest().getSession().getAttribute(ScopeHelper.USERNAME_ATTRIBUTE);
+		System.out.println("***SessionCheckerServiceImpl USER = " + user + " ID = " + sessionID);
+		SessionManager manager = SessionManager.getInstance();
+		ASLSession toReturn = manager.getASLSession(sessionID, user);
+		return toReturn;		
 	}
 
 	@Override
 	public SessionInfoBean checkSession() {
+		System.out.println("***Trying Liferay");
+		try {
+			UserLocalServiceUtil.getService();
+		}
+		catch (com.google.gwt.user.server.rpc.UnexpectedException e) {
+			System.out.println("***DEV MODE");
+			return new SessionInfoBean("","", true); //tells that you are in development mode 
+		}
+		System.out.println("***LR PORTAL DETECTED");
+		
+		
 		if (isFirstTime() == null) 
 			setFirstTimeCheck(true);
 
 		ASLSession session = getASLSession();
-		if (session == null)
-			return new SessionInfoBean("","", true); //you are in development mode and refreshed the browser	
+		if (session == null) {
+			UserLocalServiceUtil.getService();
+
+			return new SessionInfoBean("","");
+		}
 
 		String user = session.getUsername();
 		String scope = session.getScope();
@@ -71,12 +80,15 @@ public class SessionCheckerServiceImpl extends RemoteServiceServlet implements
 	}
 
 	private void setFirstTimeCheck(boolean isFirstTime) {
-
 		ASLSession session = getASLSession();
 		_log.trace("setFirstTimeCheck " + isFirstTime);
-		session.setAttribute(FIRST_TIME, isFirstTime);
-		session.increaseSessionTimeout(120000, false);
-		_log.trace("asl timeout increased by 2 minutes ");
+		if (session != null) {
+			session.setAttribute(FIRST_TIME, isFirstTime);
+			if (isFirstTime) {
+				long expiryTime = session.increaseSessionTimeout(350000, true); //bit more than 5 minutes
+				_log.trace("asl timeout increased by 5 minutes, ASL to expire at " +  new Date(new Date().getTime()+expiryTime));
+			}
+		}
 	}
 
 	private Boolean isFirstTime() {
